@@ -1,9 +1,10 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2000-2002 Free Software Foundation
+   Copyright (C) 2000-2017 Free Software Foundation
 
    Author: Philippe C.D. Robert <probert@siggraph.org>
+           Riccardo Mottola
 
    This file is part of GNUstep.
 
@@ -29,15 +30,20 @@
   Description: A ProjectType is used to create a project of a certain type. 
                With this approach this procedure can be implemented as a bundle 
  	       and therefore PC remains open for future extensions!
+
+               Options are used to further customize types.
 */
 
 #import <Foundation/Foundation.h>
 
 @class PCProject;
 
+static NSString* const PCProjectInterfaceGorm = @"GormInterface";
+static NSString* const PCProjectInterfaceRenaissance = @"RenaissanceInterface";
+
 @protocol ProjectType
 
-- (PCProject *)createProjectAt:(NSString *)path;
+- (PCProject *)createProjectAt:(NSString *)path withOption:(NSString *)option;
 
 @end
 
